==> nicotine%2B-3.0.2-1-any.pkg.tar.xz: usr/share/doc/nicotine/AUTHORS.md <==
# Nicotine+ Contributors

Have you done something for Nicotine+, and your name is missing? Please [let us know](README.md#getting-involved).

### Active

eLvErDe
- Provided Nicotine+ Trac instance
- Migrated source code from SVN to Github
- python3-miniupnpc bindings
- Developer

Kip Warner
- Developer
- Debianization
- [kip(at)thevertigo(dot)com]

Lene Preuss
- Python3 migration
- Unit and DEP-8 continuous integration testing
- [lene.preuss(at)here(dot)com]

mathiascode
- Developer
- [mail(at)mathias(dot)is]

Han Boetes
- Tester
- Documentation
- Bug hunting

alekksander
- Tester
- Redesign of some graphics

### Retired

daelstorm
- Developer
- [daelstorm(at)gmail(dot)com]

gallows (aka 'burp O')
- Developer, Packager
- Submitted Slack.Build file
- [g4ll0ws(at)gmail(dot)com]

QuinoX
- Developer

hedonist (formerly known as alexbk)
- OS X nicotine.app maintainer / developer
- Author of original pyslsk, which is used for nicotine core
- [ak(at)sensi(dot)org]

lee8oi
- Bash Commander
- New and updated /alias
- [winslaya(at)gmail(dot)com]

INMCM
- Nicotine+ topic maintainer on ubuntuforums.org
- https://ubuntuforums.org/showthread.php?t=196835

suser-guru
- Suse Linux packager
- https://dev-loki.blogspot.fr/
- Nicotine+ RPM's for Suse 9.1, 9.2, 9.3, 10.0, 10.1

osiris
- handy-man
- documentation
- some GNU/Linux packaging
- Nicotine+ on win32
- Author of Nicotine+ Guide
- [osiris.contact(at)gmail(dot)com]

Michael Labouebe (aka gfarmerfr)
- Developer
- [gfarmerfr(at)free(dot)fr]

Mutnick
- Created Nicotine+ GitHub Organization
- Developer
- [muhing(at)yahoo(dot)com]

---

# Nicotine Contributors

### Retired

Hyriand
- Founder
- [hyriand(at)thegraveyard(dot)org]

osiris
- handy-man
- [osiris.contact(at)gmail(dot)com]

SmackleFunky
- Beta tester

Wretched
- Beta tester
- Bringer of great ideas

(va)\*10^3
- Beta tester
- Designer of the old nicotine homepage and artwork (logos)

sierracat
- MacOSX tester
- Developed soulseeX

Gustavo
- Made the exception dialog
- [gjc(at)inescporto(dot)pt]

SeeSchloss
- Developer
- Made 1.0.8 win32 installer
- Created [Soulfind](https://github.com/seeschloss/soulfind), opensource Soulseek Server written in D

vasi
- Mac developer
- Packaged nicotine on OSX PowerPc
- [djvasi(at)gmail(dot)com]

---

# PySoulSeek Contributors

### Retired

Alexander Kanavin
- Created PySoulSeek
- [ak(at)sensi(dot)org]

Nir Arbel
- Helped with many protocol questions I had, and of
  course he designed and impemented the whole
  system.
- [nir(at)slsk(dot)org]
			    
Zip (Brett W. Thompson)
- I used his client code to get an initial impression
  of how the system works.
- Supplied the patch for logging chat conversations.
- [brettt(at)tfn(dot)net]

Josselin Mouette
- official Debian package maintainer
- [joss(at)debian(dot)org]

blueboy
- former unofficial Debian package maintainer
- [bluegeek(at)eresmas(dot)com]

Christian Swinehart
- Fink package maintainer
- [cswinehart(at)users(dot)sourceforge(dot)net]

Hyriand
- Patches for upload bandwidth management, banning,
  various UI improvements and more
- [hyriand(at)thegraveyard(dot)org]

Geert Kloosterman
- a script for importing windows soulseek configuration
- [geertk(at)ai(dot)rug(dot)nl]

Joe Halliwell
- Submitted a patch for optionally discarding search
  results after closing a search tab
- [s9900164(at)sms(dot)ed(dot)ac(dot)uk]

Alexey Vyskubov
- Code cleanups
- [alexey(dot)vyskubov(at)nokia(dot)com]

Jason Green
- Ignore list and auto-join checkbox, wishlists
- [smacklefunky(at)optusnet(dot)com(dot)au]

---

# Attributions

- This product includes IP2Location LITE data, available from:  
  https://www.ip2location.com

- Country flags licensed under the MIT License.  
  Copyright (c) 2013 Panayiotis Lipiridis  
  https://github.com/lipis/flag-icon-css

- tinytag licensed under the MIT License.  
  Copyright (c) 2014-2018 Tom Wallroth  
  https://github.com/devsnd/tinytag/

- UPnP code adapted from the pyupnp project. pyupnp is licensed under the MIT License.  
  Copyright (c) 2019 Dave Mulford  
  https://github.com/davemulford/pyupnp

==> nicotine%2B-3.0.6-1-any.pkg.tar.xz: usr/share/doc/nicotine/AUTHORS.md <==
# Nicotine+ Contributors

Have you done something for Nicotine+, and your name is missing? Please [let us know](README.md#getting-involved).

### Active

eLvErDe
- Provided Nicotine+ Trac instance
- Migrated source code from SVN to Github
- python3-miniupnpc bindings
- Developer

Kip Warner
- Developer
- Debianization
- [kip(at)thevertigo(dot)com]

Lene Preuss
- Python3 migration
- Unit and DEP-8 continuous integration testing
- [lene.preuss(at)here(dot)com]

mathiascode
- Developer
- [mail(at)mathias(dot)is]

Han Boetes
- Tester
- Documentation
- Bug hunting

alekksander
- Tester
- Redesign of some graphics

### Retired

daelstorm
- Developer
- [daelstorm(at)gmail(dot)com]

gallows (aka 'burp O')
- Developer, Packager
- Submitted Slack.Build file
- [g4ll0ws(at)gmail(dot)com]

QuinoX
- Developer

hedonist (formerly known as alexbk)
- OS X nicotine.app maintainer / developer
- Author of original pyslsk, which is used for nicotine core
- [ak(at)sensi(dot)org]

lee8oi
- Bash Commander
- New and updated /alias
- [winslaya(at)gmail(dot)com]

INMCM
- Nicotine+ topic maintainer on ubuntuforums.org
- https://ubuntuforums.org/showthread.php?t=196835

suser-guru
- Suse Linux packager
- https://dev-loki.blogspot.fr/
- Nicotine+ RPM's for Suse 9.1, 9.2, 9.3, 10.0, 10.1

osiris
- handy-man
- documentation
- some GNU/Linux packaging
- Nicotine+ on win32
- Author of Nicotine+ Guide
- [osiris.contact(at)gmail(dot)com]

Michael Labouebe (aka gfarmerfr)
- Developer
- [gfarmerfr(at)free(dot)fr]

Mutnick
- Created Nicotine+ GitHub Organization
- Developer
- [muhing(at)yahoo(dot)com]

---

# Nicotine Contributors

### Retired

Hyriand
- Founder
- [hyriand(at)thegraveyard(dot)org]

osiris
- handy-man
- [osiris.contact(at)gmail(dot)com]

SmackleFunky
- Beta tester

Wretched
- Beta tester
- Bringer of great ideas

(va)\*10^3
- Beta tester
- Designer of the old nicotine homepage and artwork (logos)

sierracat
- MacOSX tester
- Developed soulseeX

Gustavo
- Made the exception dialog
- [gjc(at)inescporto(dot)pt]

SeeSchloss
- Developer
- Made 1.0.8 win32 installer
- Created [Soulfind](https://github.com/seeschloss/soulfind), opensource Soulseek Server written in D

vasi
- Mac developer
- Packaged nicotine on OSX PowerPc
- [djvasi(at)gmail(dot)com]

---

# PySoulSeek Contributors

### Retired

Alexander Kanavin
- Created PySoulSeek
- [ak(at)sensi(dot)org]

Nir Arbel
- Helped with many protocol questions I had, and of
  course he designed and impemented the whole
  system.
- [nir(at)slsk(dot)org]

Zip (Brett W. Thompson)
- I used his client code to get an initial impression
  of how the system works.
- Supplied the patch for logging chat conversations.
- [brettt(at)tfn(dot)net]

Josselin Mouette
- official Debian package maintainer
- [joss(at)debian(dot)org]

blueboy
- former unofficial Debian package maintainer
- [bluegeek(at)eresmas(dot)com]

Christian Swinehart
- Fink package maintainer
- [cswinehart(at)users(dot)sourceforge(dot)net]

Hyriand
- Patches for upload bandwidth management, banning,
  various UI improvements and more
- [hyriand(at)thegraveyard(dot)org]

Geert Kloosterman
- a script for importing windows soulseek configuration
- [geertk(at)ai(dot)rug(dot)nl]

Joe Halliwell
- Submitted a patch for optionally discarding search
  results after closing a search tab
- [s9900164(at)sms(dot)ed(dot)ac(dot)uk]

Alexey Vyskubov
- Code cleanups
- [alexey(dot)vyskubov(at)nokia(dot)com]

Jason Green
- Ignore list and auto-join checkbox, wishlists
- [smacklefunky(at)optusnet(dot)com(dot)au]

---

# Attributions

- This product includes IP2Location LITE data, available from:  
  https://www.ip2location.com

- Country flags licensed under the MIT License.  
  Copyright (c) 2016 Bowtie AB  
  Copyright (c) 2018 Jack Marsh  
  https://github.com/jackiboy/flagpack

- tinytag licensed under the MIT License.  
  Copyright (c) 2014-2018 Tom Wallroth  
  https://github.com/devsnd/tinytag/

- UPnP code adapted from the pyupnp project. pyupnp is licensed under the MIT License.  
  Copyright (c) 2019 Dave Mulford  
  https://github.com/davemulford/pyupnp
